# Orbaplaw
> **Orb**ital **a**lignment analysis for **pla**ne **w**ave basis sets
>
> But now we are at the interlude of gaussian basis sets.


## Functions

**Orbaplaw** can be used to perform

+ Population analysis
  + Lowin Population
+ Orbital localization
  + Pipek-Mezey localization
  + Foster-Boys localization
  + Localized orbitalet
+ Orbital alignment
  + Spin natural orbital (SNO)
  + Fragment-aligned molecular orbital (FAMO)
+ Inter-fragment bonding analysis
  + Principal interacting orbital (PIO)
  + Natural fragment bond orbital (NFBO)


## Documents

+ [Installation](doc/INSTALLATION.md)
+ [Wavefunction processing (Gaussian-based)](doc/WFN.md)
+ [Wavefunction processing (Plane-wave-based)](doc/PW.md)
+ [Natural atomic orbital](doc/NAO.md)
+ [Principal interacting orbital analysis](doc/PIO.md)
+ [Natural fragment bond orbital analysis](doc/NFBO.md)
+ [Fragment-aligned molecular orbital analysis](doc/FAMO.md)
+ [Orbital localization](doc/LMO.md)


## Citation
Zhang, Y. Orbaplaw: Orbital alignment analysis for plane wave basis sets. https://github.com/FreemanTheMaverick/Orbaplaw, 2024.

We note that the citations of theoretical methods and programs are often omitted in research papers.
That is a discouragement for all method and program developers.
If **Orbaplaw** benefits your research, please give credit to this program and the whole method toolchain you use in your manuscript.
For example, if you have used the NFBO method, we would suggest you cite (1) the program **Orbaplaw**, (2) the original paper on NFBO and (3) the original paper on NAO (because NAO is a prerequisite for NFBO and thus part of the toolchain).
Thank you.

![](doc/please_cite.gif)
